;; Generated package description from package-lint.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "package-lint" "0.26.0.20260808.27" "A linting library for elisp package authors" '((emacs "25.1") (let-alist "1.0.6")) :commit "87bf02ca387a37094e1a0057adefa9735d880cec" :authors '(("Steve Purcell" . "steve@sanityinc.com") ("Fanael Linithien" . "fanael4@gmail.com")) :maintainer '(("Steve Purcell" . "steve@sanityinc.com") ("Fanael Linithien" . "fanael4@gmail.com")) :keywords '("lisp") :url "https://github.com/purcell/package-lint")
